NCBI Blast:Nucleotide Sequence

BLAST Results

- Your search is limited to records that include: SRX885418 Full Entrez Query

  SRX885418 [ORGN]

Edit and Resubmit Save Search Strategies [Sign in above to save your search strategy] Formatting options Download How to read this page Blast report description Click here to use the new BLAST results page Questions/comments

Formatting options
Show | Alignment as Reset form to defaults [?] These options control formatting of alignments in results pages. The default is HTML, but other formats (including plain text) are available. PSSM and PssmWithParameters are representations of Position Specific Scoring Matrices and are only available for PSI-BLAST. The Advanced view option allows the database descriptions to be sorted by various indices in a table.
Alignment View | [?] Choose how to view alignments. The default "pairwise" view shows how each subject sequence aligns individually to the query sequence. The "query-anchored" view shows how all subject sequences align to the query sequence. For each view type, you can choose to show "identities" (matching residues) as letters or dots. more...
Display | Graphical Overview Linkout Sequence Retrieval NCBI-gi CDS feature [?] Graphical Overview: Graphical Overview: Show graph of similar sequence regions aligned to query. more... NCBI-gi: Show NCBI gi identifiers. CDS feature: Show annotated coding region and translation. more...
Masking | Character: Color: [?] Masking Character: Display masked (filtered) sequence regions as lower-case or as specific letters (N for nucleotide, P for protein). Masking Color: Display masked sequence regions in the given color.
Limit results | Descriptions: Graphical overview: Alignments: Line length: [?] Descriptions: Show short descriptions for up to the given number of sequences. Alignments: Show alignments for up to the given number of sequences, in order of statistical significance. Line lenghth: Number of letters to show on one line in an alignment.
| Organism Type common name, binomial, taxid, or group name. Only 20 top taxa will be shown. exclude [?] Show only sequences from the given organism.
| Entrez query: [?] Show only those sequences that match the given Entrez query. more...
| Expect Min: Expect Max: [?] Show only sequences with expect values in the given range. more...
| Percent Identity Min: Percent Identity Max: [?] Show only sequences with percent identity values in the given range.
Format for | PSI-BLAST with inclusion threshold: [?] Format for PSI-BLAST: The Position-Specific Iterated BLAST (PSI-BLAST) program performs iterative searches with a protein query, in which sequences found in one round of search are used to build a custom score model for the next round. more... Inclusion Threshold: This sets the statistical significance threshold for including a sequence in the model used by PSI-BLAST to create the PSSM on the next iteration.

Download
Alignment Text XML ASN.1 JSON Seq-align Hit Table(text) Hit Table(csv) Multiple-file XML2 Single-file XML2 Multiple-file JSON Single-file JSON SAM | Search Strategies ASN.1 | PSSM to restart search PSSM | [?]

The Download link provides BLAST output that may be used as input to another program. This includes parseable formats such as the tabular report or XML as well as the Search Strategy files read by the BLAST+ applications. More details on the parseable (XML, tabular, and ASN.1) reports can be found at https://www.ncbi.nlm.nih.gov/books/NBK153387/

The following formats are offered under the Alignment section:
1). "Text". Non-HTML standard BLAST report.
2). "XML". XML report based upon the DTD at https://www.ncbi.nlm.nih.gov/data_specs/dtd/NCBI_BlastOutput.dtd
3). "ASN.1". Alignment written out in Abstract Syntax Notation 1.
4). "JSON Seq-align". Alignment written out in JSON.
4). "Hit Table(text)". The tabular report as text.
5). "Hit Table(csv)". The tabular report ready for import into spread-sheet programs like Excel.
6). "XML2". New XML format described at ftp://ftp.ncbi.nlm.nih.gov/blast/documents/NEWXML/xml2.pdf.
7). "JSON". New JSON format described at ftp://ftp.ncbi.nlm.nih.gov/blast/documents/NEWXML/xml2.pdf.
8). "SAM". Sequence Alignment Map format.

XML2 and JSON can be downloaded either as one file per query (multiple-file) or one file for all queries (single-file). These formats are listed as Multiple-file XML2 (and JSON) or Single-file XML (and JSON).

The following report is offered under the Search Strategy section:
1). "ASN.1" Search Strategy. A record of the parameters, query, and database used in the search. This file can be used to start a stand-alone BLAST search, see https://www.ncbi.nlm.nih.gov/books/NBK1763/#CmdLineAppsManual.I455_BLAST_search_stra

- There was a problem with the search. Please, contact Help Desk and include RID HX11AFVP01R

  Problem with taxonomic lookup and/or entrez, please consider changing.

# Job title: Nucleotide Sequence

Results for:
[?]

Your BLAST job specified more than one input sequence. This box lets you choose which input sequence to show BLAST results for.

RID
  HX11AFVP01R (Expires on 07-28 15:37 pm)

Query ID
  lcl|Query_20201
  lcl|Query_20201
Description
  None
Molecule type
  nucleic acid
Query Length
  12

Database Name
Description
  See details
Program
  BLASTN 2.10.1+ Citation

Blast search databases information
Database | Description | Posted Date
--- | --- | ---

Reference
Stephen F. Altschul, Thomas L. Madden, Alejandro A. Schäffer, Jinghui Zhang, Zheng Zhang, Webb Miller, and David J. Lipman (1997), "Gapped BLAST and PSI-BLAST: a new generation of protein database search programs", Nucleic Acids Res. 25:3389-3402.

- No significant similarity found. For reasons why,click here

Other reports: Search Summary [Taxonomy reports] [MSA viewer]

Search Parameters
Search parameter name | Search parameter value
--- | ---
Program | blastn
Word size | 11
Expect value | 10
Hitlist size | 500
Match/Mismatch scores | 2,-3
Gapcosts | 5,2
Low Complexity Filter | Yes
Filter string | L;m;
Genetic Code | 1

Database
Database parameter name | Database parameter value
--- | ---
Posted date |
Number of letters | 0
Number of sequences | 0
Entrez query | Includes: SRX885418 Excludes: None

Karlin-Altschul statistics
Params | Ungapped | Gapped
--- | --- | ---
Lambda |  |
K |  |
H |  |

Results Statistics
Results Statistics parameter name | Results Statistics parameter value
--- | ---

## Graphic Summary

### Distribution of the top Blast Hits on subject sequences [?]

The graphic is an overview of the database sequences aligned to the query sequence. These are represented horizontal bars colored coded by score and showing the extent of the alignment on the query sequence. Separate aligned regions on the same database sequence are connected by a thin grey line. Mousing over an alignment shows the database sequence title. Clicking an alignment displays a box with more details about the alignment and link to the sequence alignment itself in the Alignments section of the report.

Mouse over to see the title, click to show alignments
Color key for alignment scores
<40
40-50
50-80
80-200
>=200
Query

## Descriptions

Load next setPrevious Match

## Alignments